<?php
namespace Woopromotion\Elementorwidgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 *
 * Elementor flash deals section widget.
 *
 * @since 1.0
 */
class Coupon_Code_Card extends Widget_Base {

	public function get_name() {
		return 'woopromotion-coupon-code-card';
	}

	public function get_title() {
		return esc_html__( 'Coupon Code Card', 'woopromotion' );
	}

	public function get_icon() {
		return 'eicon-product-upsell';
	}

	public function get_categories() {
		return [ 'woopromotion-elements' ];
	}

	protected function register_controls() {

		$repeater = new \Elementor\Repeater();

        // ----------------------------------------  Content Settings ------------------------------
        $this->start_controls_section(
            'woopromotion_coupon_code_table_content',
            [
                'label' => esc_html__( 'Coupon Code Table', 'woopromotion' ),
            ]
        );

        $this->add_control(
            'title', [
                'label'     => esc_html__( 'Title', 'woopromotion' ),
                'label_block' => true,
                'default' => esc_html__( 'ON SALE NOW', 'woopromotion' ),
                'type'  => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'offer_value', [
                'label'     => esc_html__( 'Offer Value', 'woopromotion' ),
                'label_block' => true,
                'default' => esc_html__( '30%', 'woopromotion' ),
                'type'  => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'offer_type', [
                'label'     => esc_html__( 'Offer Type', 'woopromotion' ),
                'label_block' => true,
                'default' => esc_html__( 'OFF', 'woopromotion' ),
                'type'  => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'coupon_description',
            [
                'label' => esc_html__( 'Description', 'woopromotion' ),
                'default' => esc_html__( 'Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry\'s standard dummy text', 'woopromotion' ),
                'type' => \Elementor\Controls_Manager::WYSIWYG
            ]
        );
        $this->add_control(
            'coupon_btn', [
                'label'     => esc_html__( 'Button', 'woopromotion' ),
                'label_block' => true,
                'default' => esc_html__( 'GET A CODE', 'woopromotion' ),
                'type'  => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'coupon_code', [
                'label'     => esc_html__( 'Coupon Code', 'woopromotion' ),
                'label_block' => true,
                'type'  => Controls_Manager::TEXT,
                'default' => 'LV5MAY14'
            ]
        );
        $this->end_controls_section(); // End section

        /******** Content Style **************/

        $this->start_controls_section(
            'woopromotion_card_body_style',
            [
                'label' => esc_html__( 'Card Body', 'woopromotion' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'card_body_margin',
            [
                'label' => esc_html__( 'Margin', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-coupon-card-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'card_body_padding',
            [
                'label' => esc_html__( 'Padding', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-coupon-card-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'card_body_border',
                'label' => esc_html__( 'Border', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-coupon-card-wrapper',
            ]
        );
        $this->add_responsive_control(
            'card_body_radius',
            [
                'label' => esc_html__( 'Border Radius', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-coupon-card-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'card_body_box_shadow',
                'label' => esc_html__( 'Box Shadow', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-coupon-card-wrapper',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'card_body_bg_color',
                'label' => esc_html__( 'Background Color', 'woopromotion' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .woopromotion-coupon-card-wrapper',
            ]
        );
        $this->end_controls_section(); // Content Style End

        /******** Card title **************/

        $this->start_controls_section(
            'woopromotion_coupon_card_title_style',
            [
                'label' => esc_html__( 'Title', 'woopromotion' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'title_color',
            [
                'label' => esc_html__( 'Title Color', 'woopromotion' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .coupon-card-title h2' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'label' => esc_html__( 'Typography', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .coupon-card-title h2',
            ]
        );
        $this->add_control(
            'title_wrapper_heading',
            [
                'label' => esc_html__( 'Title Wrapper', 'woopromotion' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'title_border',
                'label' => esc_html__( 'Title Wrapper Border', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .coupon-card-title',
            ]
        );
        $this->add_responsive_control(
            'title_radius',
            [
                'label' => esc_html__( 'Title Wrapper Border Radius', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .coupon-card-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'title_box_shadow',
                'label' => esc_html__( 'Title Wrapper Box Shadow', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .coupon-card-title',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'title_bg_color',
                'label' => esc_html__( 'Title Wrapper Background', 'woopromotion' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .coupon-card-title',
            ]
        );
        $this->add_responsive_control(
            'title_margin',
            [
                'label' => esc_html__( 'Title Wrapper Margin', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .coupon-card-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'title_padding',
            [
                'label' => esc_html__( 'Title Wrapper Padding', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .coupon-card-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_section(); // title Style End

        /******** Card Discount Area **************/
        $this->start_controls_section(
            'woopromotion_coupon_card_offer_style',
            [
                'label' => esc_html__( 'Discount', 'woopromotion' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'discount_value_heading',
            [
                'label' => esc_html__( 'Discount Value', 'woopromotion' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'after',
            ]
        );
        $this->add_control(
            'discount_color',
            [
                'label' => esc_html__( 'Text Color', 'woopromotion' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-coupon-card-wrapper .discount' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'discount_typography',
                'label' => esc_html__( 'Typography', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-coupon-card-wrapper .discount',
            ]
        );
        $this->add_control(
            'discount_type_heading',
            [
                'label' => esc_html__( 'Discount Type', 'woopromotion' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'after',
            ]
        );
        $this->add_control(
            'discount_type_color',
            [
                'label' => esc_html__( 'Type Text Color', 'woopromotion' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-coupon-card-wrapper .discount .type' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'discount_type_typography',
                'label' => esc_html__( 'Typography', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-coupon-card-wrapper .discount .type',
            ]
        );
        $this->add_control(
            'discount_wrapper_heading',
            [
                'label' => esc_html__( 'Discount Wrapper', 'woopromotion' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'after',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'discount_border',
                'label' => esc_html__( 'Discount Wrapper Border', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-coupon-card-wrapper .discount',
            ]
        );
        $this->add_responsive_control(
            'discount_radius',
            [
                'label' => esc_html__( 'Discount Wrapper Border Radius', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-coupon-card-wrapper .discount' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'discount_box_shadow',
                'label' => esc_html__( 'Discount Wrapper Box Shadow', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-coupon-card-wrapper .discount',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'discount_bg_color',
                'label' => esc_html__( 'Discount Wrapper Background', 'woopromotion' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .woopromotion-coupon-card-wrapper .discount',
            ]
        );
        $this->add_control(
            'discount_wrapper_downarrow_color',
            [
                'label' => esc_html__( 'Wrapper Down Arrow Color', 'woopromotion' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-coupon-card-wrapper .discount.woopromotion-coupon-card-discount:after' => 'border-top-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'discount_margin',
            [
                'label' => esc_html__( 'Title Wrapper Margin', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-coupon-card-wrapper .discount' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'discount_padding',
            [
                'label' => esc_html__( 'Title Wrapper Padding', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-coupon-card-wrapper .discount' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_section(); // Discount Style End

        /******** Card Descriptions Area **************/

        $this->start_controls_section(
            'woopromotion_coupon_card_descriptions_style',
            [
                'label' => esc_html__( 'Descriptions', 'woopromotion' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'descriptions_color',
            [
                'label' => esc_html__( 'Text Color', 'woopromotion' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-coupon-card-wrapper .coupon-card-description' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'descriptions_typography',
                'label' => esc_html__( 'Typography', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-coupon-card-wrapper .coupon-card-description',
            ]
        );
        
        $this->add_control(
            'descriptions_wrapper_heading',
            [
                'label' => esc_html__( 'Descriptions Wrapper', 'woopromotion' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'after',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'descriptions_border',
                'label' => esc_html__( 'Wrapper Border', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-coupon-card-wrapper .coupon-card-description',
            ]
        );
        $this->add_responsive_control(
            'descriptionst_radius',
            [
                'label' => esc_html__( 'Wrapper Border Radius', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-coupon-card-wrapper .coupon-card-description' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'descriptions_box_shadow',
                'label' => esc_html__( 'Wrapper Box Shadow', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-coupon-card-wrapper .coupon-card-description',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'descriptions_bg_color',
                'label' => esc_html__( 'Wrapper Background', 'woopromotion' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .woopromotion-coupon-card-wrapper .coupon-card-description',
            ]
        );
        $this->add_responsive_control(
            'descriptions_margin',
            [
                'label' => esc_html__( 'Wrapper Margin', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-coupon-card-wrapper .coupon-card-description' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'descriptions_padding',
            [
                'label' => esc_html__( 'Wrapper Padding', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-coupon-card-wrapper .coupon-card-description' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_section(); // Descriptions Style End

        /******** Card Discount Code Area **************/

        $this->start_controls_section(
            'woopromotion_coupon_card_discount_code_style',
            [
                'label' => esc_html__( 'Discount Code', 'woopromotion' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'discount_code_color',
            [
                'label' => esc_html__( 'Code Text Color', 'woopromotion' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-coupon-card-wrapper .coupon .coupon-code' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'discount_code_typography',
                'label' => esc_html__( 'Typography', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-coupon-card-wrapper .coupon .coupon-code',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'discount_code_border',
                'label' => esc_html__( 'Border', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-coupon-card-wrapper .coupon .coupon-code',
            ]
        );
        $this->add_responsive_control(
            'discount_code_radius',
            [
                'label' => esc_html__( 'Wrapper Border Radius', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-coupon-card-wrapper .coupon .coupon-code' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'discount_code_box_shadow',
                'label' => esc_html__( 'Wrapper Box Shadow', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-coupon-card-wrapper .coupon .coupon-code',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'discount_code_bg_color',
                'label' => esc_html__( 'Wrapper Background', 'woopromotion' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .woopromotion-coupon-card-wrapper .coupon .coupon-code',
            ]
        );
        $this->add_control(
            'discount_code_wrapper_heading',
            [
                'label' => esc_html__( 'Discount Code Wrapper', 'woopromotion' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'after',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'discount_code_wrapper_border',
                'label' => esc_html__( 'Wrapper Border', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-coupon-card-wrapper .coupon',
            ]
        );
        $this->add_responsive_control(
            'discount_code_wrapper_radius',
            [
                'label' => esc_html__( 'Wrapper Border Radius', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-coupon-card-wrapper .coupon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'discount_code_wrapper_box_shadow',
                'label' => esc_html__( 'Wrapper Box Shadow', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-coupon-card-wrapper .coupon',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'discount_code_wrapper_bg_color',
                'label' => esc_html__( 'Wrapper Background', 'woopromotion' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .woopromotion-coupon-card-wrapper .coupon',
            ]
        );
        $this->add_responsive_control(
            'discount_code_wrapper_margin',
            [
                'label' => esc_html__( 'Wrapper Margin', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-coupon-card-wrapper .coupon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'discount_code_wrapper_padding',
            [
                'label' => esc_html__( 'Wrapper Padding', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-coupon-card-wrapper .coupon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_section(); // discount code Style End

        /******** Button Style **************/
        $this->start_controls_section(
            'woopromotion_btn_style',
            [
                'label' => esc_html__( 'Button Style', 'woopromotion' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        //  Controls tab start
        $this->start_controls_tabs( 'btn_tabs_start' );

        //  Controls tab For Normal
        $this->start_controls_tab(
            'btn_normal',
            [
                'label' => esc_html__( 'Normal', 'woopromotion' ),
            ]
        );        
        $this->add_control(
            'btn_color',
            [
                'label' => esc_html__( 'Text Color', 'woopromotion' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn-code.open-code' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typography',
                'label' => esc_html__( 'Typography', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .btn-code.open-code',
            ]
        );
        $this->add_responsive_control(
            'btn_margin',
            [
                'label' => esc_html__( 'Margin', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .btn-code.open-code' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'btn_padding',
            [
                'label' => esc_html__( 'Padding', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .btn-code.open-code' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'btn_border',
                'label' => esc_html__( 'Border', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .btn-code.open-code',
            ]
        );
        $this->add_responsive_control(
            'btn_radius',
            [
                'label' => esc_html__( 'Border Radius', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .btn-code.open-code' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'btn_box_shadow',
                'label' => esc_html__( 'Box Shadow', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .btn-code.open-code',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'btn_bg_color',
                'label' => esc_html__( 'Button Background Color', 'woopromotion' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .btn-code.open-code',
            ]
        );

        $this->end_controls_tab(); // End Controls tab

        //  Controls tab For Hover
        $this->start_controls_tab(
            'btn_hover_normal',
            [
                'label' => esc_html__( 'Hover', 'woopromotion' ),
            ]
        );

        $this->add_control(
            'btn_hover_color',
            [
                'label' => esc_html__( 'Hover Text Color', 'woopromotion' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn-code.open-code:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'btn_hover_border',
                'label' => esc_html__( 'Hover Border', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .btn-code.open-code:hover',
            ]
        );
        $this->add_responsive_control(
            'btn_hover_radius',
            [
                'label' => esc_html__( 'Hover Border Radius', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .btn-code.open-code:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'btn_hover_box_shadow',
                'label' => esc_html__( 'Hover Box Shadow', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .btn-code.open-code:hover',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'btn_hover_bg_color',
                'label' => esc_html__( 'Hover Button Background Color', 'woopromotion' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .btn-code.open-code:hover',
            ]
        );

        $this->end_controls_tab(); // End Controls tab

        $this->end_controls_tabs(); //  end controls tabs section
        $this->end_controls_section(); // Button Style End

	}

	protected function render() {
        $settings = $this->get_settings();
        ?>
        <div class="woopromotion-coupon-card-wrapper">
            <?php
            //
            if( !empty( $settings['title'] ) ) {
                echo '<div class="coupon-card-title"><h2>'.esc_html( $settings['title'] ).'</h2></div>';
            }
            ?>
            <div class="discount woopromotion-coupon-card-discount">
                <?php
                // 
                if( !empty( $settings['offer_value'] ) ) {
                   echo '<span>'.esc_html( $settings['offer_value'] ).'</span>'; 
                }
                //
                if( !empty( $settings['offer_type'] ) ) {
                    echo '<div class="type">'.esc_html( $settings['offer_type'] ).'</div>';
                }
                ?>
            </div>
            <?php 
            //
            if( !empty( $settings['coupon_description'] ) ) {
                echo '<div class="coupon-card-description">'.wp_kses( $settings['coupon_description'], 'post' ).'</div>';
            }
            ?>
            <div class="coupon bg-color-blue">
                <?php
                // Button
                if( !empty( $settings['coupon_btn'] ) ) {
                    echo '<button class="btn-code open-code">'.esc_html( $settings['coupon_btn'] ).'</button>';
                }
                //
                if( !empty( $settings['coupon_code'] ) ) {
                    echo '<div class="coupon-code">'.esc_html( $settings['coupon_code'] ).'</div>';
                }
                ?>
            </div>
        </div>
        <?php
        
    }
	
}
