<?php
namespace Woopromotion\Elementorwidgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 *
 * Elementor flash deals products widget.
 *
 * @since 1.0
 */
class Flash_Deals_Products extends Widget_Base {

	public function get_name() {
		return 'woopromotion-flash-deals-products';
	}

	public function get_title() {
		return esc_html__( 'Flash Deals Products', 'woopromotion' );
	}

	public function get_icon() {
		return 'eicon-products';
	}

	public function get_categories() {
		return [ 'woopromotion-elements' ];
	}

	protected function register_controls() {

        // ----------------------------------------  Content Settings ------------------------------
        $this->start_controls_section(
            'woopromotion_flash_deals_product_content',
            [
                'label' => esc_html__( 'Content Settings', 'woopromotion' ),
            ]
        );
        
        $this->add_control(
            'number', [
                'label'     => esc_html__( 'Product Per Page', 'woopromotion' ),
                'type'      => Controls_Manager::NUMBER,
                'default'   => '8'
            ]
        );

        $this->end_controls_section(); // End section


        /******** Wrapper Style **************/

        $this->start_controls_section(
            'woopromotion_flash_deals_wrapper_style',
            [
                'label' => esc_html__( 'Section Wrapper Style', 'woopromotion' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_responsive_control(
            'flash_deals_section_wrapper_margin',
            [
                'label' => esc_html__( 'Margin', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-flash-deals' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'flash_deals_section_wrapper_padding',
            [
                'label' => esc_html__( 'Padding', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-flash-deals' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'flash_deals_section_wrapper_border',
                'label' => esc_html__( 'Border', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-flash-deals',
            ]
        );
        $this->add_responsive_control(
            'flash_deals_section_wrapper_radius',
            [
                'label' => esc_html__( 'Border Radius', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-flash-deals' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'flash_deals_section_wrapper_box_shadow',
                'label' => esc_html__( 'Box Shadow', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-flash-deals',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'flash_deals_section_wrapper_bg_color',
                'label' => esc_html__( 'Button Background Color', 'woopromotion' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .woopromotion-flash-deals',
            ]
        );
        $this->end_controls_section(); // Wrapper Style End

	}

	protected function render() {

        $settings = $this->get_settings();
            
        //
        echo '<div class="woopromotion-flash-deals">';
        echo '<div  class="woocommerce">';
        // Query
        $args = array(
            'post_type'      => 'product',
            'posts_per_page' => !empty( $settings['number'] ) ? $settings['number'] : '-1',
            'order'          => 'ASC',
            'meta_query'     => array(
                array(
                    'key'           => '_sale_price',
                    'value'         => 0,
                    'compare'       => '>',
                    'type'          => 'numeric'
                )
            )
        );
        $loop = new \WP_Query( $args );
        if ( $loop->have_posts() ) {

            do_action( 'woocommerce_before_shop_loop' );
           woocommerce_product_loop_start();
                while ( $loop->have_posts() ) {
                    $loop->the_post();

                   do_action( 'woocommerce_shop_loop' );
                    wc_get_template_part( 'content', 'product' );
                }
            woocommerce_product_loop_end();
            do_action( 'woocommerce_after_shop_loop' );
        } else {
            do_action( 'woocommerce_no_products_found' );
        }

        wp_reset_postdata();
        echo '</div>';
        echo '</div>';
        
    }
	
}
