<?php
namespace Woopromotion\Elementorwidgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 *
 * Elementor flash deals section widget.
 *
 * @since 1.0
 */
class Flash_Deals_Section extends Widget_Base {

	public function get_name() {
		return 'woopromotion-flash-deals-section';
	}

	public function get_title() {
		return esc_html__( 'Flash Deals Countdown Section', 'woopromotion' );
	}

	public function get_icon() {
		return 'eicon-products-archive';
	}

	public function get_categories() {
		return [ 'woopromotion-elements' ];
	}

	protected function register_controls() {

		$repeater = new \Elementor\Repeater();

        // ----------------------------------------  Content Settings ------------------------------
        $this->start_controls_section(
            'woopromotion_flash_deals_countdown_content',
            [
                'label' => esc_html__( 'Content Settings', 'woopromotion' ),
            ]
        );

        $this->add_control(
            'start_date', [
                'label'     => esc_html__( 'Start Date', 'woopromotion' ),
                'description' => esc_html__( 'Please follow the example date format, September 25, 2021 6:40 PM', 'woopromotion'),
                'label_block' => true,
                'type'      => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'end_date', [
                'label'     => esc_html__( 'End Date', 'woopromotion' ),
                'description' => esc_html__( 'Please follow the example date format, September 25, 2021 6:40 PM', 'woopromotion'),
                'label_block' => true,
                'type'      => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'title', [
                'label'     => esc_html__( 'Title', 'woopromotion' ),
                'type'      => Controls_Manager::TEXT,
                'default'   => 'On Sale Now'
            ]
        );
        $this->add_control(
            'number', [
                'label'     => esc_html__( 'Product Per Section', 'woopromotion' ),
                'type'      => Controls_Manager::NUMBER,
                'default'   => '4'
            ]
        );
        $this->add_control(
            'btn_label', [
                'label'     => esc_html__( 'Button Label', 'woopromotion' ),
                'type'      => Controls_Manager::TEXT,
                'default'   => 'View All'
            ]
        );
        $this->add_control(
            'btn_url',
            [
                'label' => esc_html__( 'Link', 'woopromotion' ),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => esc_html__( 'https://your-link.com', 'woopromotion' ),
                'show_external' => true,
                'default' => [
                    'url' => '',
                    'is_external' => true,
                    'nofollow' => true,
                ],
            ]
        );

        $this->end_controls_section(); // End section

        /******** Wrapper Style **************/

        $this->start_controls_section(
            'woopromotion_flash_deals_wrapper_style',
            [
                'label' => esc_html__( 'Section Wrapper Style', 'woopromotion' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_responsive_control(
            'flash_deals_section_wrapper_margin',
            [
                'label' => esc_html__( 'Margin', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-flash-deals' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'flash_deals_section_wrapper_padding',
            [
                'label' => esc_html__( 'Padding', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-flash-deals' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'flash_deals_section_wrapper_border',
                'label' => esc_html__( 'Border', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-flash-deals',
            ]
        );
        $this->add_responsive_control(
            'flash_deals_section_wrapper_radius',
            [
                'label' => esc_html__( 'Border Radius', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-flash-deals' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'flash_deals_section_wrapper_box_shadow',
                'label' => esc_html__( 'Box Shadow', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-flash-deals',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'flash_deals_section_wrapper_bg_color',
                'label' => esc_html__( 'Button Background Color', 'woopromotion' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .woopromotion-flash-deals',
            ]
        );
        $this->end_controls_section(); // Wrapper Style End

        /******** Content Style **************/

        $this->start_controls_section(
            'woopromotion_flash_deals_content_style',
            [
                'label' => esc_html__( 'Countdown Area Style', 'woopromotion' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'text_color', [
                'label'     => esc_html__( 'Text Color', 'woopromotion' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#111',
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-flash-deals-coutdown' => 'color: {{VALUE}};'
                ],
            ]
        );
        $this->add_control(
            'title_color', [
                'label'     => esc_html__( 'Title Color', 'woopromotion' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#f57224',
                'selectors' => [
                    '{{WRAPPER}} .inner-flash-deals-coutdown h6' => 'color: {{VALUE}};'
                ],
            ]
        );
        $this->add_responsive_control(
            'flash_deals_wrapper_margin',
            [
                'label' => esc_html__( 'Margin', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-flash-deals-coutdown' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'flash_deals_wrapper_padding',
            [
                'label' => esc_html__( 'Padding', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-flash-deals-coutdown' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'flash_deals_wrapper_border',
                'label' => esc_html__( 'Border', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-flash-deals-coutdown',
            ]
        );
        $this->add_responsive_control(
            'flash_deals_wrapper_radius',
            [
                'label' => esc_html__( 'Border Radius', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-flash-deals-coutdown' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'flash_deals_wrapper_box_shadow',
                'label' => esc_html__( 'Box Shadow', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-flash-deals-coutdown',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'flash_deals_wrapper_bg_color',
                'label' => esc_html__( 'Button Background Color', 'woopromotion' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .woopromotion-flash-deals-coutdown',
            ]
        );
        $this->end_controls_section(); // Content Style End

        /******** Countdown Style **************/

        $this->start_controls_section(
            'woopromotion_countdown_style',
            [
                'label' => esc_html__( 'Countdown Timer Style', 'woopromotion' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'countdown_color',
            [
                'label' => esc_html__( 'Text Color', 'woopromotion' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .inner-flash-deals-coutdown .flash-deals-section-countdown span' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'countdown_border',
                'label' => esc_html__( 'Border', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .inner-flash-deals-coutdown .flash-deals-section-countdown span',
            ]
        );
        $this->add_responsive_control(
            'countdown_radius',
            [
                'label' => esc_html__( 'Border Radius', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .inner-flash-deals-coutdown .flash-deals-section-countdown span' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'countdown_box_shadow',
                'label' => esc_html__( 'Box Shadow', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .inner-flash-deals-coutdown .flash-deals-section-countdown span',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'countdown_bg_color',
                'label' => esc_html__( 'Button Background Color', 'woopromotion' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .inner-flash-deals-coutdown .flash-deals-section-countdown span',
            ]
        );
        $this->end_controls_section(); // Countdown Style End

        /******** Button Style **************/
        $this->start_controls_section(
            'woopromotion_btn_style',
            [
                'label' => esc_html__( 'Button Style', 'woopromotion' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        //  Controls tab start
        $this->start_controls_tabs( 'btn_tabs_start' );

        //  Controls tab For Normal
        $this->start_controls_tab(
            'btn_normal',
            [
                'label' => esc_html__( 'Normal', 'woopromotion' ),
            ]
        );        
        $this->add_control(
            'btn_color',
            [
                'label' => esc_html__( 'Text Color', 'woopromotion' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-flash-deals-coutdown a' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typography',
                'label' => esc_html__( 'Typography', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-flash-deals-coutdown a',
            ]
        );
        $this->add_responsive_control(
            'btn_margin',
            [
                'label' => esc_html__( 'Margin', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-flash-deals-coutdown a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'btn_padding',
            [
                'label' => esc_html__( 'Padding', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-flash-deals-coutdown a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'btn_border',
                'label' => esc_html__( 'Border', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-flash-deals-coutdown a',
            ]
        );
        $this->add_responsive_control(
            'btn_radius',
            [
                'label' => esc_html__( 'Border Radius', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-flash-deals-coutdown a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'btn_box_shadow',
                'label' => esc_html__( 'Box Shadow', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-flash-deals-coutdown a',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'btn_bg_color',
                'label' => esc_html__( 'Button Background Color', 'woopromotion' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .woopromotion-flash-deals-coutdown a',
            ]
        );

        $this->end_controls_tab(); // End Controls tab

        //  Controls tab For Hover
        $this->start_controls_tab(
            'btn_hover_normal',
            [
                'label' => esc_html__( 'Hover', 'woopromotion' ),
            ]
        );

        $this->add_control(
            'btn_hover_color',
            [
                'label' => esc_html__( 'Hover Text Color', 'woopromotion' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-flash-deals-coutdown a:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'btn_hover_border',
                'label' => esc_html__( 'Hover Border', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-flash-deals-coutdown a:hover',
            ]
        );
        $this->add_responsive_control(
            'btn_hover_radius',
            [
                'label' => esc_html__( 'Hover Border Radius', 'woopromotion' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .woopromotion-flash-deals-coutdown a:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'btn_hover_box_shadow',
                'label' => esc_html__( 'Hover Box Shadow', 'woopromotion' ),
                'selector' => '{{WRAPPER}} .woopromotion-flash-deals-coutdown a:hover',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'btn_hover_bg_color',
                'label' => esc_html__( 'Hover Button Background Color', 'woopromotion' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .woopromotion-flash-deals-coutdown a:hover',
            ]
        );

        $this->end_controls_tab(); // End Controls tab

        $this->end_controls_tabs(); //  end controls tabs section
        $this->end_controls_section(); // Button Style End


	}

	protected function render() {

        $settings = $this->get_settings();
               
        $startDate = !empty( $settings['start_date'] ) ? $settings['start_date'] : '';
        $endTime = !empty( $settings['end_date'] ) ? $settings['end_date'] : '';
        //
        echo '<div class="woopromotion-flash-deals">';
            echo '<div class="woopromotion-flash-deals-coutdown">';
                echo '<div class="inner-flash-deals-coutdown">';
                        // Title
                        if( !empty( $settings['title'] ) ) {
                            echo '<h6>'.esc_html( $settings['title'] ).'</h6>';
                        }
                        //
                        if( !empty( $startDate ) ) {
                            echo \Woopromotion\Classes\Countdown_Timer::countdownTimer( $startDate, $endTime, 'flash-deals-section-countdown', 'short' );
                        }
                        
                echo '</div>';
                // Button
                $target = '_self';
                if( !empty( $settings['btn_url']['is_external'] ) && $settings['btn_url']['is_external'] == 'on' ) {
                    $target = '_blank';
                }

                if( !empty( $settings['btn_label'] ) && !empty( $settings['btn_url']['url'] ) ) {
                    echo '<a href="'.esc_url( $settings['btn_url']['url'] ).'" target="'.esc_attr( $target ).'">'.esc_html( $settings['btn_label'] ).'</a>';
                }
                
            echo '</div>';
        echo '<div  class="woocommerce">';
        // Query
        $args = array(
            'post_type'      => 'product',
            'posts_per_page' => !empty( $settings['number'] ) ? $settings['number'] : '4',
            'order'          => 'ASC',
            'meta_query'     => array(
                array(
                    'key'           => '_sale_price',
                    'value'         => 0,
                    'compare'       => '>',
                    'type'          => 'numeric'
                )
            )
        );
        $loop = new \WP_Query( $args );
        if ( $loop->have_posts() ) {

            do_action( 'woocommerce_before_shop_loop' );
            woocommerce_product_loop_start();
                while ( $loop->have_posts() ) {
                    $loop->the_post();

                   do_action( 'woocommerce_shop_loop' );
                    wc_get_template_part( 'content', 'product' );
                }
            woocommerce_product_loop_end();
            do_action( 'woocommerce_after_shop_loop' );
        } else {
            do_action( 'woocommerce_no_products_found' );
        }

        wp_reset_postdata();
        echo '</div>';
        echo '</div>';
        
    }
	
}
