<?php
/**
 * Plugin Name:       WooPromotion
 * Plugin URI:        https://www.persianscript.ir
 * Description:       WooCommerce product promotion sale countdown and badge manager.
 * Version:           1.0.6
 * Author:            پرشین اسکریپت
 * Author URI:        https://www.persianscript.ir
 * License:           GPL v2 or later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain:       woopromotion
 * Domain Path:       /languages
 */

/**
 * Define all constant
 *
 */

// Block Direct access
if( !defined( 'ABSPATH' ) ){ die( 'You should not access this file directly!.' ); }

// Define Constants for direct access alert message.
if( !defined( 'WOOPROMOTION_ALERT_MSG' ) )
	define( 'WOOPROMOTION_ALERT_MSG', esc_html__( 'You should not access this file directly.!', 'woopromotion' ) );

// Version constant
if( !defined( 'WOOPROMOTION_VERSION' ) ) {
	define( 'WOOPROMOTION_VERSION', '1.0.6' );
}

// Plugin dir path constant
if( !defined( 'WOOPROMOTION_DIR_PATH' ) ) {
	define( 'WOOPROMOTION_DIR_PATH', trailingslashit( plugin_dir_path( __FILE__ ) ) );
}
// Plugin dir url constant
if( !defined( 'WOOPROMOTION_DIR_URL' ) ) {
	define( 'WOOPROMOTION_DIR_URL', trailingslashit( plugin_dir_url( __FILE__ ) ) );
}
// Plugin dir admin assets url constant
if( !defined( 'WOOPROMOTION_DIR_ADMIN_ASSETS_URL' ) ) {
	define( 'WOOPROMOTION_DIR_ADMIN_ASSETS_URL', trailingslashit( WOOPROMOTION_DIR_URL . 'admin/assets' ) );
}
// Admin dir path
if( !defined( 'WOOPROMOTION_DIR_ADMIN' ) ) {
	define( 'WOOPROMOTION_DIR_ADMIN', trailingslashit( WOOPROMOTION_DIR_PATH.'admin' ) );
}
// Inc dir path
if( !defined( 'WOOPROMOTION_DIR_INC' ) ) {
	define( 'WOOPROMOTION_DIR_INC', trailingslashit( WOOPROMOTION_DIR_PATH.'inc' ) );
}

//
require_once WOOPROMOTION_DIR_PATH.'vendor/autoload.php';

final class Woopromotion {

	private static $instance = null;

	function __construct() {

		add_action( 'admin_notices', [ __CLASS__, 'admin_notice_required_plugin' ] );
		add_action( 'wp_enqueue_scripts', [ __CLASS__, 'enqueue' ] );
		add_action( 'wp_footer', [ __CLASS__, 'add_canvas_bar' ] );
		add_action( 'init', [__CLASS__, 'init'] );
		//
		\Woopromotion\Elementorwidgets\Woopromotion_El_Widgets_Init::instance();
		//
		new Woopromotion\Classes\Woo_Hooks();
		new Woopromotion\Classes\Hooks();
		new Woopromotion\Classes\Woo_Product_Tab();
	}

	public static function getInstance() {

		if( is_null( self::$instance ) ) {
			self::$instance = new self;
		}
		return self::$instance;
	}

	public static function init() {
		//
		new Woopromotion\Admin\Admin();
		new Woopromotion\Meta\Meta_Config();
		new \Woopromotion\Classes\Badges();
	}
	public static function add_canvas_bar() {
		
		$canvasPromoBar = \Woopromotion\Inc\Helper::getOption('active_canvas_promo_bar');
		if( !empty( $canvasPromoBar ) ) {
			$canvasHeader = new Woopromotion\Classes\Canvas_Header();
			$canvasHeader->getCanvasHeader();
		}
		//
		if( !empty( \Woopromotion\Inc\Helper::getOption('active_canvas_cart_progress_bar') ) ) {
			$canvasCartBarShow = \Woopromotion\Inc\Helper::getOption('canvas_cart_bar_show_page');
			$pages = !empty( $canvasCartBarShow ) ? $canvasCartBarShow : '';
			if( is_page( $pages ) || is_shop() ) {

				$canvasHeader = new Woopromotion\Classes\Canvas_Cart_Progress();
				$canvasHeader->getCanvasCartProgress();

			}
		}
		
	}
	public static function enqueue() {

		wp_enqueue_style( 'ticker', WOOPROMOTION_DIR_URL.'assets/css/ticker.min.css', [], '1.0.1', 'all', false );
		wp_enqueue_style( 'woopromotion', WOOPROMOTION_DIR_URL.'assets/css/woopromotion.css', [], '1.0.1', 'all', false );
		wp_enqueue_script( 'acmeticker', WOOPROMOTION_DIR_URL.'assets/js/acmeticker.min.js', ['jquery'], '1.0.1', 'all', true );
		wp_enqueue_script( 'woopromotion', WOOPROMOTION_DIR_URL.'assets/js/woopromotion.js', ['jquery'], '1.0.1', 'all', true );

		wp_localize_script(
		        'woopromotion', 
		        'woopromotionobj', 
		        array(
		        	"is_tooltip" => \Woopromotion\Inc\Helper::getOption('active_badge_tooltip'),
		        	"start_count_text" => esc_html__( 'Start From', 'woopromotion' ),
		        	"end_count_text"   => esc_html__( 'End in', 'woopromotion' ),
		        	"tickeropt"   => [
		        		'type' 	    => \Woopromotion\Inc\Helper::getOption('ticker_type'), 
		        		'direction' => \Woopromotion\Inc\Helper::getOption('ticker_direction'), 
		        		'controls'  => \Woopromotion\Inc\Helper::getOption('ticker_controls'), 
		        		'speed'     => \Woopromotion\Inc\Helper::getOption('ticker_speed'), 
		        	],
		        )
    		);

    		// Custom Style
		$options = get_option('woopromotion_options');

		$productCountdownColor = !empty( $options['product_countdown_color'] ) ? $options['product_countdown_color'] : '#ff3d00';
		$shopCountdownColor = !empty( $options['shop_countdown_color'] ) ? $options['shop_countdown_color'] : '#ff3d00';

		$progressTextColor = !empty( $options['progress_text_color'] ) ? $options['progress_text_color'] : '#d3232a';
		$progressBarBgColor = !empty( $options['progress_bar_bg_color'] ) ? $options['progress_bar_bg_color'] : '#eee';
		$progressBgColor = !empty( $options['progress_bg_color'] ) ? $options['progress_bg_color'] : '#d3232a';
		$shopCountdownAlign = !empty( $options['shop_countdown_align'] ) ? $options['shop_countdown_align'] : 'flex-start';

        $custom_css = "
                .flash-sale-details-inner .product-flash-countdown span{
            		color: {$productCountdownColor};
                }
                .shop-flash-countdown span {
                	color: {$shopCountdownColor};
                }
                .stock-progress {
                	background:{$progressBarBgColor};
                }
                .stock-progress-bar {
                	background:{$progressBgColor};
                }
                .stock-progress-wrapper span {
                	color:{$progressTextColor};
                }
                .woopromotion-shop-price-down-badge,
                .related .stock-progress-wrapper,
                .stock-progress-wrapper.shop-stock-bar,
                .shop-flash-countdown {
		  justify-content: {$shopCountdownAlign};
		}
                ";
        wp_add_inline_style( 'woopromotion', $custom_css );

	}

	public static function admin_notice_required_plugin() {

		if( Woopromotion\Inc\Helper::is_elementor_active() != 'active' ):
	    	?>
	    	<div class="notice notice-warning is-dismissible">
			<?php
			printf( '<p style="padding: 10px 0px"><strong>WooPromotion</strong> %1$s <strong>Elementor</strong> %2$s</p>', esc_html__( 'requires', 'woopromotion' ), esc_html__( 'to be installed and activated to work properly.', 'woopromotion' ) );
			echo '<p><a href="https://wordpress.org/plugins/elementor/" target="_blank">'.esc_html__( 'Install', 'woopromotion' ).'</a><p>';
			?>
		</div>
	    	<?php
		endif;
		//
		if( !Woopromotion\Inc\Helper::is_woo_active() ):
		?>
		<div class="notice notice-warning is-dismissible">
			<?php
			printf( '<p style="padding: 10px 0px"><strong>WooPromotion</strong> %1$s <strong>WooCommerce</strong> %2$s</p>', esc_html__( 'requires', 'woopromotion' ), esc_html__( 'to be installed and activated to work properly.', 'woopromotion' ) );
			echo '<p><a href="https://wordpress.org/plugins/woocommerce/" target="_blank">'.esc_html__( 'Install', 'woopromotion' ).'</a><p>';
			?>
		</div>
		<?php
		endif;
	}

}

Woopromotion::getInstance();
